<?php

/**
 * ReduxFramework Barebones Sample Config File
 * For full documentation, please visit: http://docs.reduxframework.com/
 */

if (!defined('HEYLONE_CORE__PLUGIN_PATH')) {
	return;
}
// This is your option name where all the Redux data is stored.
$opt_name = "imic_options";

/**
 * ---> SET ARGUMENTS
 * All the possible arguments for Redux.
 * For full documentation on arguments, please refer to: https://github.com/ReduxFramework/ReduxFramework/wiki/Arguments
 * */

$theme = wp_get_theme(); // For use with some settings. Not necessary.

$args = array(
	// TYPICAL -> Change these values as you need/desire
	'opt_name'             => $opt_name,
	// This is where your data is stored in the database and also becomes your global variable name.
	'display_name'         => $theme->get('Name'),
	// Name that appears at the top of your panel
	'display_version'      => $theme->get('Version'),
	// Version that appears at the top of your panel
	'menu_type'            => 'menu',
	//Specify if the admin menu should appear or not. Options: menu or submenu (Under appearance only)
	'allow_sub_menu'       => true,
	// Show the sections below the admin menu item or not
	'menu_title'           => esc_html__('Theme Options', 'heylone'),
	'page_title'           => esc_html__('Theme Options', 'heylone'),
	// You will need to generate a Google API key to use this feature.
	// Please visit: https://developers.google.com/fonts/docs/developer_api#Auth
	'google_api_key'       => '',
	// Set it you want google fonts to update weekly. A google_api_key value is required.
	'google_update_weekly' => false,
	// Must be defined to add google fonts to the typography module
	'async_typography'     => true,
	// Use a asynchronous font on the front end or font string
	//'disable_google_fonts_link' => true,                    // Disable this in case you want to create your own google fonts loader
	'admin_bar'            => true,
	// Show the panel pages on the admin bar
	'admin_bar_icon'       => 'dashicons-portfolio',
	// Choose an icon for the admin bar menu
	'admin_bar_priority'   => 50,
	// Choose an priority for the admin bar menu
	'global_variable'      => '',
	// Set a different name for your global variable other than the opt_name
	'dev_mode'             => false,
	// Show the time the page took to load, etc
	'update_notice'        => true,
	// If dev_mode is enabled, will notify developer of updated versions available in the GitHub Repo
	'customizer'           => true,
	// Enable basic customizer support
	//'open_expanded'     => true,                    // Allow you to start the panel in an expanded way initially.
	//'disable_save_warn' => true,                    // Disable the save warning when a user changes a field

	// OPTIONAL -> Give you extra features
	'page_priority'        => null,
	// Order where the menu appears in the admin area. If there is any conflict, something will not show. Warning.
	'page_parent'          => '',
	// For a full list of options, visit: http://codex.wordpress.org/Function_Reference/add_submenu_page#Parameters
	'page_permissions'     => 'manage_options',
	// Permissions needed to access the options panel.
	'menu_icon'            => '',
	// Specify a custom URL to an icon
	'last_tab'             => '',
	// Force your panel to always open to a specific tab (by id)
	'page_icon'            => 'icon-themes',
	// Icon displayed in the admin panel next to your menu_title
	'page_slug'            => '_options',
	// Page slug used to denote the panel
	'save_defaults'        => true,
	// On load save the defaults to DB before user clicks save or not
	'default_show'         => false,
	// If true, shows the default value next to each field that is not the default value.
	'default_mark'         => '',
	// What to print by the field's title if the value shown is default. Suggested: *
	'show_import_export'   => true,
	// Shows the Import/Export panel when not used as a field.

	// CAREFUL -> These options are for advanced use only
	'transient_time'       => 60 * MINUTE_IN_SECONDS,
	'output'               => true,
	// Global shut-off for dynamic CSS output by the framework. Will also disable google fonts output
	'output_tag'           => true,
	// Allows dynamic CSS to be generated for customizer and google fonts, but stops the dynamic CSS from going to the head
	// 'footer_credit'     => '',                   // Disable the footer credit of Redux. Please leave if you can help it.

	// FUTURE -> Not in use yet, but reserved or partially implemented. Use at your own risk.
	'database'             => '',
	// possible: options, theme_mods, theme_mods_expanded, transient. Not fully functional, warning!

	'use_cdn'              => true,
	// If you prefer not to use the CDN for Select2, Ace Editor, and others, you may download the Redux Vendor Support plugin yourself and run locally or embed it in your code.

	//'compiler'             => true,

	// HINTS
	'hints'                => array(
		'icon'          => 'el el-question-sign',
		'icon_position' => 'right',
		'icon_color'    => 'lightgray',
		'icon_size'     => 'normal',
		'tip_style'     => array(
			'color'   => 'light',
			'shadow'  => true,
			'rounded' => false,
			'style'   => '',
		),
		'tip_position'  => array(
			'my' => 'top left',
			'at' => 'bottom right',
		),
		'tip_effect'    => array(
			'show' => array(
				'effect'   => 'slide',
				'duration' => '500',
				'event'    => 'mouseover',
			),
			'hide' => array(
				'effect'   => 'slide',
				'duration' => '500',
				'event'    => 'click mouseleave',
			),
		),
	)
);

// ADMIN BAR LINKS -> Setup custom links in the admin bar menu as external items.
$args['share_icons'][] = array(
	'url'   => 'https://www.facebook.com/imithemes',
	'title' => 'Like us on Facebook',
	'icon'  => 'el el-facebook'
);
$args['share_icons'][] = array(
	'url'   => 'https://twitter.com/imithemes',
	'title' => 'Follow us on Twitter',
	'icon'  => 'el el-twitter'
);

// Panel Intro text -> before the form
if (!isset($args['global_variable']) || $args['global_variable'] !== false) {
	if (!empty($args['global_variable'])) {
		$v = $args['global_variable'];
	} else {
		$v = str_replace('-', '_', $args['opt_name']);
	}
} else { }

Redux::setArgs($opt_name, $args);

// Set the help sidebar
$content = __('<p>This is the sidebar content, HTML is allowed.</p>', 'heylone');
Redux::setHelpSidebar($opt_name, $content);

// -> START Basic Fields
Redux::setSection($opt_name, array(
	'icon' => 'el-icon-cogs',
	'icon_class' => 'icon-large',
	'title' => __('General', 'heylone'),
	'fields' => array(
        array(
            'id' => 'enable_maintenance',
            'type' => 'switch',
            'title' => __('Enable Maintenance', 'heylone'),
            'subtitle' => __('Enable the themes in maintenance mode.', 'heylone'),
            "default" => 0,
            'on' => 'Enabled',
            'off' => 'Disabled',
        ),
        array(
            'id' => 'custom_favicon',
            'type' => 'media',
            'compiler' => 'true',
            'title' => __('Custom favicon', 'heylone'),
            'desc' => __('Upload a image that will represent your website favicon', 'heylone')
        ),
        array(
            'id' => 'tracking-code',
            'type' => 'textarea',
            'title' => __('Tracking Code', 'heylone'),
            'subtitle' => __('Paste your Google Analytics (or other) tracking code here. This will be added into the footer template of your theme.', 'heylone'),
            'validate' => 'js',
            'desc' => 'Validate that it\'s javascript!',
        ),
        array(
            'id' => 'custom_admin_login_logo',
            'type' => 'media',
            'url' => true,
            'title' => __('Custom admin login logo', 'heylone'),
            'compiler' => 'true',
        ),
		array(
            'id' => 'enable_spinner',
            'type' => 'switch',
            'title' => __('Enable Preloader', 'heylone'),
            'subtitle' => __('Enable theme to preload with waiting spinner. ', 'heylone'),
            "default" => 1,
            'on' => 'Enabled',
            'off' => 'Disabled',
        ),
	)
));

Redux::setSection($opt_name, array(
	'icon' => 'el-icon-website',
	'icon_class' => 'icon-large',
	'title' => __('Header Options', 'heylone'),
	'fields' => array(
        array(
            'id' => 'upload_site_logo',
            'type' => 'media',
            'url' => true,
            'title' => __('Upload Site Logo', 'heylone'),
            'compiler' => 'true',
        ),
        array(
            'id' => 'show_header_alltime',
            'type' => 'switch',
            'title' => __('Show Header', 'heylone'),
            'subtitle' => __('Show header all time instead of Header opening button.', 'heylone'),
            "default" => 0,
            'on' => 'Yes',
            'off' => 'No',
        ),
	)
));

Redux::setSection($opt_name, array(
	'icon' => 'el-icon-screen',
	'title' => __('Footer Options', 'heylone'),
	'fields' => array(
        array(
            'id' => 'enable_footer',
            'type' => 'switch',
            'title' => __('Enable Footer', 'heylone'),
            'subtitle' => __('Enable the footer section.', 'heylone'),
            "default" => 1,
        ),
        array(
            'id' => 'footer_facebook_link',
            'type' => 'text',
            'title' => __('Facebook URL', 'heylone'),
            'desc' => __('Enter your facebook profile URL.', 'heylone'),
            'default' => __('https://www.facebook.com/', 'heylone')
        ),
        array(
            'id' => 'footer_twitter_link',
            'type' => 'text',
            'title' => __('Twitter URL', 'heylone'),
            'desc' => __('Enter your twitter profile URL.', 'heylone'),
            'default' => __('https://twitter.com/', 'heylone')
        ),
        array(
            'id' => 'footer_instagram_link',
            'type' => 'text',
            'title' => __('Instagram URL', 'heylone'),
            'desc' => __('Enter your instagram profile URL..', 'heylone'),
            'default' => __('https://instagram.com/', 'heylone')
        ),
        array(
            'id' => 'footer_pinterest_link',
            'type' => 'text',
            'title' => __('Pinterest URL', 'heylone'),
            'desc' => __('Enter your Pinterest profile URL.', 'heylone')
        ),
        array(
            'id' => 'footer_google_plus_link',
            'type' => 'text',
            'title' => __('Google Plus URL', 'heylone'),
            'desc' => __('Enter your Google Plus profile URL.', 'heylone')
        ),
        array(
            'id' => 'footer_youtube_link',
            'type' => 'text',
            'title' => __('Youtube URL', 'heylone'),
            'desc' => __('Enter your Youtube Channel URL.', 'heylone')
        ),
        array(
            'id' => 'footer_vimeo_link',
            'type' => 'text',
            'title' => __('Vimeo URL', 'heylone'),
            'desc' => __('Enter your Vimeo Channel URL.', 'heylone')
        ),
        array(
            'id' => 'footer_dribbble_link',
            'type' => 'text',
            'title' => __('Dribbble URL', 'heylone'),
            'desc' => __('Enter your Dribbble portfolio URL.', 'heylone')
        ),
        array(
            'id' => 'footer_linkedin_link',
            'type' => 'text',
            'title' => __('Linkedin URL', 'heylone'),
            'desc' => __('Enter your Linkedin profile URL.', 'heylone')
        ),
        array(
            'id' => 'footer_vk_link',
            'type' => 'text',
            'title' => __('VK URL', 'heylone'),
            'desc' => __('Enter your VK profile URL.', 'heylone')
        ),
        array(
            'id' => 'footer_copyright_text',
            'type' => 'text',
            'title' => __('Footer Copyright Text', 'heylone'),
            'default' => __('&copy; 2014 Heylone Studio. All Rights Reserved.', 'heylone')
        ),
	),
));

Redux::setSection($opt_name, array(
	'icon' => 'el-icon-ok',
	'title' => __('Color Scheme', 'heylone'),
	'fields' => array(
        array(
            'id' => 'theme_color_type',
            'type' => 'button_set',
            'compiler' => true,
            'title' => __('Color choice', 'heylone'),
            'subtitle' => __('Select the page layout type', 'heylone'),
            'options' => array(
                '0' => __('Pre-Defined Color Schemes', 'heylone'),
                '1' => __('Custom Color', 'heylone')
            ),
            'default' => '0',
        ),
        array(
            'id' => 'theme_color_scheme',
            'type' => 'select',
            'required' => array('theme_color_type', 'equals', '0'),
            'title' => __('Theme Color Scheme', 'heylone'),
            'subtitle' => __('Select your themes alternative color scheme.', 'heylone'),
            'options' => array('color1.css' => 'color1.css', 'color2.css' => 'color2.css', 'color3.css' => 'color3.css', 'color4.css' => 'color4.css', 'color5.css' => 'color5.css', 'color6.css' => 'color6.css', 'color7.css' => 'color7.css', 'color8.css' => 'color8.css', 'color9.css' => 'color9.css', 'color10.css' => 'color10.css', 'color11.css' => 'color11.css', 'color12.css' => 'color12.css'),
            'default' => 'color1.css',
        ),
        array(
            'id' => 'custom_theme_color',
            'type' => 'color',
            'required' => array('theme_color_type', 'equals', '1'),
            'title' => __('Custom Theme Color', 'heylone'),
            'subtitle' => __('Pick a color for the template.', 'heylone'),
            'validate' => 'color',
	    	'transparent' => false,	
        ),
	),
));

Redux::setSection($opt_name, array(
	'icon' => 'el-icon-chevron-up',
	'title' => __('X/Twitter Profile', 'heylone'),
	'desc' => 'X handle button to show at the team section',
	'fields' => array(
        /*array(
            'id' => 'twitter-consumer-key',
            'type' => 'text',
            'title' => __('Consumer Key', 'heylone'),
            'desc' => __('Enter your consumer key of twitter application for getting latest twitter feeds.', 'heylone')
        ),
        array(
            'id' => 'twitter-consumer-key-secret',
            'type' => 'text',
            'title' => __('Consumer Key Secret', 'heylone'),
            'desc' => __('Enter your consumer key secret of twitter application for getting latest twitter feeds.', 'heylone')
        ),
        array(
            'id' => 'twitter-access-token',
            'type' => 'text',
            'title' => __('Access Token', 'heylone'),
            'desc' => __('Enter your access token of twitter application for getting latest twitter feeds.', 'heylone')
        ),
        array(
            'id' => 'twitter-access-token-secret',
            'type' => 'text',
            'title' => __('Access Token Secret', 'heylone'),
            'desc' => __('Enter your access token secret of twitter application for getting latest twitter feeds.', 'heylone')
        ),
        array(
            'id' => 'twitter-number-of-tweets',
            'type' => 'text',
            'title' => __('Number of Tweets', 'heylone'),
            'desc' => __('Enter Number of Tweets for getting latest twitter feeds.', 'heylone'),
         'default' =>1,
        )*/
        array(
            'id' => 'twitter-handle',
            'type' => 'text',
            'title' => __('X/Twitter ID/Handle', 'heylone'),
            'desc' => __('Enter your X/Twitter profile username. Example: imithemes', 'heylone'),
         	'default' => '',
        ),
        array(
            'id' => 'twitter-handle-url',
            'type' => 'text',
            'title' => __('X/Twitter profile URL', 'heylone'),
            'desc' => __('Enter your X/Twitter profile full URL. Example: https://twitter.com/imithemes', 'heylone'),
         	'default' => '',
        )
	),
));
Redux::setSection($opt_name, array(
	'icon' => 'el-icon-css',
	'title' => __('Custom CSS/JS', 'heylone'),
	'fields' => array(
		array(
			'id' => 'custom_css',
			'type' => 'ace_editor',
			'title' => __('CSS Code', 'heylone'),
			'subtitle' => __('Paste your CSS code here.', 'heylone'),
			'mode' => 'css',
			'theme' => 'monokai',
			'desc' => '',
			'default' => "#header{\nmargin: 0 auto;\n}"
		),
		array(
			'id' => 'custom_js',
			'type' => 'ace_editor',
			'title' => __('JS Code', 'heylone'),
			'subtitle' => __('Paste your JS code here.', 'heylone'),
			'mode' => 'javascript',
			'theme' => 'chrome',
			'desc' => '',
			'default' => "jQuery(document).ready(function(){\n\n});"
		)
	),
));

Redux::setSection($opt_name, array(
	'title' => __('Import / Export', 'heylone'),
	'desc' => __('Import and Export your Theme Options settings from file, text or URL.', 'heylone'),
	'icon' => 'el-icon-refresh',
	'fields' => array(
		array(
			'id' => 'opt-import-export',
			'type' => 'import_export',
			'title' => __('Import Export', 'heylone'),
			'subtitle' => __('Save and restore your Theme options', 'heylone'),
			'full_width' => false,
		),
	),
)); 

/*
 * <--- END SECTIONS
 */
