<?php
/*
 *
 * 	imic Framework Theme Functions
 * 	------------------------------------------------
 * 	imic Framework
 * 	Copyright imic  2014 - http://www.imicreation.com/
 * 	imic_theme_activation()
 * 	imic_maintenance_mode()
 * 	imic_custom_login_logo()
 * 	imic_global_include_classes()
 * 	imic_admin_css()
 *      imic_analytics()
 *      imic_get_post_type_list_key()
 *      imic_admin_scripts_for_portfolio_data() 
 *      imic_get_all_pages()
 *      imic_slider_speed()
 */
/* MAINTENANCE MODE
  ================================================== */
if (!function_exists('imic_maintenance_mode')) {
    function imic_maintenance_mode() {
        $options = get_option('imic_options');
        $custom_logo = $custom_logo_output = $maintenance_mode = "";
        if (isset($options['upload_site_logo'])) {
            $custom_logo = $options['upload_site_logo'];
        }
        if (!empty($custom_logo['url'])) {
            $custom_logo_output = '<img src="' . $custom_logo['url'] . '" alt="maintenance" style="margin: 0 auto; display: block;" />';
        } else {
            $custom_logo_output = '<img src="' . get_template_directory_uri() . '/images/logo.png" alt="maintenance" style="margin: 0 auto; display: block;" />';
        }
        if (isset($options['enable_maintenance'])) {
            $maintenance_mode = $options['enable_maintenance'];
        } else {
            $maintenance_mode = false;
        }
        if ($maintenance_mode) {
            if (!current_user_can('edit_themes') || !is_user_logged_in()) {
                wp_die($custom_logo_output . '<p style="text-align:center">' . __('We are currently in maintenance mode, please check back shortly.', 'heylone') . '</p>');
            }
        }
    }
    add_action('get_header', 'imic_maintenance_mode');
}
/* CUSTOM LOGIN LOGO
  ================================================== */
if (!function_exists('imic_custom_login_logo')) {
    function imic_custom_login_logo() {
        $options = get_option('imic_options');
        $custom_logo = "";
        if (isset($options['custom_admin_login_logo'])) {
            $custom_logo = $options['custom_admin_login_logo'];
        }
        if (!empty($custom_logo['url'])) {
            echo '<style type="text/css">
					.login h1 a { background-image:url(' . $custom_logo['url'] . ') !important; height: auto !important; width: auto !important; background-size: auto !important; }
				</style>';
        } else {
            echo '<style type="text/css">
					.login h1 a { background-image:url(' . get_template_directory_uri() . '/images/logo.png) !important; }
				</style>';
        }
    }
    add_action('login_head', 'imic_custom_login_logo');
}
/* DYNAMIC GLOBAL INCLUDE CLASSES
  ================================================== */
if (!function_exists('imic_global_include_classes')) {
    function imic_global_include_classes() {
        // INCLUDED FUNCTIONALITY SETUP
        global $post, $imic_has_portfolio, $imic_has_blog, $imic_has_progress_bar, $imic_has_imagebanner;
        $imic_inc_class = "";
        if ($imic_has_portfolio) {
            $imic_inc_class .= "has-portfolio ";
        }
        if ($imic_has_blog) {
            $imic_inc_class .= "has-blog ";
        }
        $content = $post->post_content;
        if (function_exists('has_shortcode')) {
            if (has_shortcode($content, 'product_category') || has_shortcode($content, 'featured_products') || has_shortcode($content, 'products')) {
                $imic_inc_class .= "has-products ";
                $imic_include_isotope = true;
            }
        }
        if ($imic_has_progress_bar) {
            $imic_inc_class .= "has-progress-bar ";
        }
        if ($imic_has_imagebanner) {
            $imic_inc_class .= "has-imagebanner ";
        }
        return $imic_inc_class;
    }
}
/* Show analytics code in footer 
  ================================================== */
if (!function_exists('imic_analytics')) {
    function imic_analytics() {
        $options = get_option('imic_options');
        $tracking_code = (isset($options['tracking-code']))?$options['tracking-code']:'';
        if ($tracking_code <> "") {
            echo ''.$tracking_code;
        }
    }
    add_action('wp_footer', 'imic_analytics');
}
/* Get all portfolios in select options of meta fields 
  ================================================== */
if (!function_exists('imic_get_post_type_list_key')) {
    function imic_get_post_type_list_key($post_type) {
        $posts_by_tag = get_posts(array('post_type' => $post_type, 'post_status' => 'publish', 'posts_per_page' => -1));
        $post_list = array();
        foreach ($posts_by_tag as $post) {
            $post_list[$post->ID] = $post->post_title;
        }
        return $post_list;
    }
}
/* Get all portfolios data to show on Portfolio admin page 
  ================================================== */
if (!function_exists('imic_admin_scripts_for_portfolio_data')) {
    function imic_admin_scripts_for_portfolio_data() {
        $porfolio_data_for_append='';
        if (is_admin()) {
            $variable_post_id = '';
            if (!empty($_GET['post']) || !empty($_POST['post_ID'])) {
                $variable_post_id = (isset($_GET['post'])) ? $_GET['post'] : $_POST['post_ID'];
            }
            $page_template = get_post_meta($variable_post_id, '_wp_page_template', 'true');
            if (!empty($variable_post_id) && $page_template == 'template-portfolio.php') {
               $portfolio_hiddenitem = get_post_meta($variable_post_id,'imic_portfolio_hiddenitem','true');
                $data_in_post = explode(',', $portfolio_hiddenitem);
                $posts = get_posts(array(
                    'post_type' => 'portfolio',
                    'post__in' => $data_in_post,
                    'orderby' => 'post__in',
                    'posts_per_page' => -1
                ));
              $porfolio_data_for_append.= '<table cellspacing="0" style="display: table;"><thead><tr><th colspan="4" class="col-title">' . __('Title', 'heylone') . '</th></tr></thead>';
                if (!empty($posts[0]->ID)) {
                    foreach ($posts as $post) {
                        $porfolio_data_for_append.='<tr class="col-heading"><td class="col-title" colspan="3">' . $post->post_title . '<input type="hidden" class="col-id" value="' . $post->ID . '" name="imic_theme_meta"></td><td class="col-edit"><a class="delete-inline">' . __("Delete", "heylone") . '</a></td></tr>';
                    }
                }
                $porfolio_data_for_append.='</table>';
               }
            }
        return $porfolio_data_for_append;
    }
}
/* Get all child pages of front page
  ================================================== */
if(!function_exists('imic_get_all_pages')){
function imic_get_all_pages(){
$page_list = array();
if(get_option('show_on_front')=='page'){
$args = array(
'child_of' =>get_option('page_on_front'),
 'post_type' => 'page',
 'post_status' => 'publish',
 'sort_order' => 'ASC',
 'sort_column' => 'menu_order',
); 
$pages = get_pages($args);
if(!empty($pages)){
foreach ($pages as $post) {
$basename = basename(get_permalink($post->ID));
$page_list[$basename] = $post->post_title;
}}          
}
return $page_list;
}}
if(!function_exists('imic_slider_speed')){
function imic_slider_speed(){
    $slider_speed = array();
    for($i=1;$i<=20;$i++){
        $value= 1000*$i;
     $slider_speed[$value] =$i.__(' sec','heylone');  
    }
return $slider_speed;
}}
?>