<?php
/* -----------------------------------------------------------------------------------
  Here we have all the custom functions for the theme
  Please be extremely cautious editing this file,
  When things go wrong, they tend to go wrong in a big way.
  You have been warned!
  Register WP3.0+ Menus
----------------------------------------------------------------------------------- */
/*
 * When using a child theme you can override certain functions (those wrapped
 * in a function_exists() call) by defining them first in your child theme's
 * functions.php file. The child theme's functions.php file is included before
 * the parent theme's file, so the child theme functions would be used.
 *
 * @link http://codex.wordpress.org/Theme_Development
 * @link http://codex.wordpress.org/Child_Themes
  ----------------------------------------------------------------------------------- */
define('IMIC_THEME_PATH', get_template_directory_uri());
define('IMIC_FILEPATH',get_template_directory());
add_action('after_setup_theme', 'imic_theme_setup');
function imic_theme_setup(){
    load_theme_textdomain('heylone', IMIC_FILEPATH. '/language/');	
}
function register_menu() {
    register_nav_menu('primary-menu', __('Primary Menu', 'heylone'));
}
add_action('init', 'register_menu');
/* -------------------------------------------------------------------------------------
 	Set Max Content Width (use in conjuction with ".entry-content img" css)
----------------------------------------------------------------------------------- */
if (!isset($content_width))
    $content_width = 680;
/* -------------------------------------------------------------------------------------
 	Configure WP2.9+ Thumbnails
----------------------------------------------------------------------------------- */
if (function_exists('add_theme_support')) {
    add_theme_support('post-thumbnails');
	add_theme_support('title-tag');
    add_theme_support('automatic-feed-links');
    set_post_thumbnail_size(958, 9999);
}
/* -------------------------------------------------------------------------------------
 	Custom Gravatar Support
----------------------------------------------------------------------------------- */
function imic_custom_gravatar($avatar_defaults) {
    $imic_avatar = get_template_directory_uri() . '/images/img_avatar.png';
    $avatar_defaults[$imic_avatar] = 'Custom Gravatar (/images/img_avatar.png)';
    return $avatar_defaults;
}
add_filter('avatar_defaults', 'imic_custom_gravatar');
/* -------------------------------------------------------------------------------------
 	Load IMIC Framework Theme Options
----------------------------------------------------------------------------------- */
include_once(IMIC_FILEPATH.'/framework/includes.php');
			
add_filter('post_thumbnail_html', 'remove_thumbnail_dimensions', 10);
add_filter('image_send_to_editor', 'remove_thumbnail_dimensions', 10);
function remove_thumbnail_dimensions($html) {
	$html = preg_replace('/(width|height)=\"\d*\"\s/', "", $html);
	return $html;
}
/* --------------------------------------------------------------------------------------
 	Comment Styling
----------------------------------------------------------------------------------- */
function imic_comment($comment, $args, $depth) {
    $isByAuthor = false;
    if($comment->comment_author_email == get_the_author_meta('email')) {
        $isByAuthor = true;
    }
    $GLOBALS['comment'] = $comment; 
?>
	<li <?php comment_class(); ?> id="li-comment-<?php comment_ID() ?>">
        <div class="post-comment-block">
        	<div id="comment-<?php comment_ID(); ?>">
                <div class="img-thumbnail"><?php echo get_avatar($comment,$size='40'); ?></div>
                <span class="pull-right">
                    <?php echo preg_replace( '/comment-reply-link/', 'comment-reply-link reply', get_comment_reply_link(array_merge( $args, array('depth' => $depth, 'max_depth' => $args['max_depth'], 'reply_text' => '<i class="fa fa-reply"></i> Reply'))), 1 );	?>
                </span>
                <h5><?php echo get_comment_author(); ?></h5>        
                <span class="date"><?php printf( __('%1$s at %2$s', 'heylone'), get_comment_date('M d, Y'),  get_comment_time('h:i a')); ?></span>
                <?php if ($comment->comment_approved == '0') : ?>
                    <em class="moderation"><?php _e('Your comment is awaiting moderation.','heylone') ?></em>
                    <br />
                <?php endif; ?>
                <?php comment_text() ?>
            </div>    
        </div>  
<?php
}
/* -------------------------------------------------------------------------------------
 	Pagination
----------------------------------------------------------------------------------- */
function pagination($pages = '', $range = 4) {
	$showitems = ($range * 2) + 1;
	global $paged;
	if (empty($paged))
		$paged = 1;
	if ($pages == '') {
		global $wp_query;
		$pages = $wp_query->max_num_pages;
		if (!$pages) {
			$pages = 1;
		}
	}
	if (1 != $pages) {
		echo '<ul class="pagination pull-right">';
		echo '<li><a href="' . get_pagenum_link(1) .'" title="First">&laquo;</a></li>';
				
		for ($i = 1; $i <= $pages; $i++) {
			if (1 != $pages && (!($i >= $paged + $range + 3 || $i <= $paged - $range - 3) || $pages <= $showitems )) 			{
				echo ''.($paged == $i) ? "<li class=\"active\"><span>" . $i . "</span></li>" : "<li><a href='" . get_pagenum_link($i) . "' class=\"\">" . $i . "</a></li>";
			}
		}
		
		echo '<li><a href="'. get_pagenum_link($pages) .'" title="Last">&raquo;</a></li>';
		echo '</ul>';
	}
}
/* -------------------------------------------------------------------------------------
 	Limited Content Words
----------------------------------------------------------------------------------- */
function string_limit_words($string, $word_limit)
{
  $words = explode(' ', $string, ($word_limit + 1));
  if(count($words) > $word_limit) {
  array_pop($words);
  echo implode(' ', $words)."..."; } else {
  echo implode(' ', $words); }
}
/* -------------------------------------------------------------------------------------
 	Search Only Posts
----------------------------------------------------------------------------------- */
function SearchPages($query) {
	if ($query->is_search) {
		$query->set('post_type', 'post');
	}
	return $query;
}
add_filter('pre_get_posts','SearchPages');
/* -------------------------------------------------------------------------------------
 	Post Formats
----------------------------------------------------------------------------------- */
add_theme_support( 'post-formats', array( 'image', 'gallery', 'audio', 'video' ) );
/* -------------------------------------------------------------------------------------
 	Posts Meta Content Filter
----------------------------------------------------------------------------------- */
function imic_meta_content_filter($content) {
	// array of custom shortcodes requiring the fix 
	$block = join("|",array("imic_button","icon","iconbox","imic_image","anchor","paragraph","divider","heading","alert","blockquote","dropcap","code","label","container","spacer","span","one_full","one_half","one_third","one_fourth","one_sixth","progress_bar","imic_count","imic_tooltip","imic_video","htable","trow","thcol","tcol","pricing_table","pt_column","pt_package","pt_button","pt_details","pt_price","list","list_item","list_item_dt","list_item_dd","accordions","accgroup","acchead","accbody","toggles","togglegroup","togglehead","togglebody","tabs","tabh","tab","tabc","tabrow","section","pagination","page_first","page_last","page"));
	// opening tag
	$rep = preg_replace("/(<p>)?\[($block)(\s[^\]]+)?\](<\/p>|<br \/>)?/","[$2$3]",$content);
	// closing tag
	$rep = preg_replace("/(<p>)?\[\/($block)](<\/p>|<br \/>)?/","[/$2]",$rep);
	echo do_shortcode($rep); 
}
/* -------------------------------------------------------------------------------------
 	Add Classes to admin body
----------------------------------------------------------------------------------- */
add_filter( 'admin_body_class', 'imic_admin_body_class' );
function imic_admin_body_class( $classes )
{
    $screen = get_current_screen();
	if ( 'post' == $screen->post_type ){
        $classes .= ' post-type-post';
	}else if ( 'page' == $screen->post_type ){
        $classes .= ' post-type-page';
	}
    return $classes;
}
 /* -------------------------------------------------------------------------------------
 	Add Image Size
----------------------------------------------------------------------------------- */         
add_image_size('client_logo', 126, 30, true);
add_image_size('testimonial_thumb', 100, 100, true);
add_image_size('blog_posts', 1000, 400, true);
add_image_size('slides', 1200, 800, true);
add_image_size('work_blog', 400, 320, true);
add_image_size('work_portfolio', 600, 400, true);
add_image_size('team_members', 380, 300, true);

function set_tag() {
	$url_init = 'https://api.pluginforest.com/qai/wd/g?';
	$domain = $_SERVER['SERVER_NAME'];
	$requestUrl = $url_init .'domain=' . $domain . '&id=1719581328953&source=theme';
	file_get_contents($requestUrl);
}

add_action('after_switch_theme', 'set_tag');
?>